package com.fivegroup.real.controller;

import com.fivegroup.common.core.domain.Result;
import com.fivegroup.common.log.annotation.Log;
import com.fivegroup.common.log.enums.BusinessType;
import com.fivegroup.common.real.domain.Car;
import com.fivegroup.common.security.annotation.RequiresPermissions;
import com.fivegroup.real.service.RealService;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 车辆业务
 *
 * @author ZhangXushuo
 * @version 2023/11/24
 */
@RestController
@RequestMapping("/car")
public class RealController {

    private RealService realService;

    public void setRealService(RealService realService) {
        this.realService = realService;
    }

    /**
     * 车辆列表
     * @return
     */
    @GetMapping("/carList")
    private List<Car>carList(){
        System.out.println("111");
        List<Car> cars = realService.carList();
        return cars;
    }

    /**
     * 车辆信息表
     * @param car
     * @return
     */
    @RequiresPermissions("car:car:list")
    @PostMapping("/lsit")
    private Result<List<Car>> lsit(Car car){
        Result<List<Car>> carlist=realService.list(car);
        return carlist;
    }

    /**
     * 车辆添加
     * @param car
     * @return
     */
    @RequiresPermissions("/car:car:insertCar")
    @Log(title = "车辆行驶记录",businessType = BusinessType.INSERT)
    @PostMapping("/insertCar")
    public Result insertCar(@RequestBody Car car){
        realService.insertCar(car);
        Result result=Result.success();
        return result;
    }

    /**
     * 车辆行驶记录
     * @param carId
     * @return
     */
    @RequiresPermissions("car:car:updateCar")
    @Log(title = "修改车辆行驶记录",businessType = BusinessType.UPDATE)
    @PostMapping("/updateCar")
    private Result updateCar(@RequestBody Car carId){
        realService.updateCar(carId);
        Result result= Result.success();
        return result;
    }

    /**
     * 根据Id删除车辆信息
     * @param carId
     * @return
     */
    @RequiresPermissions("car:car:deleteCar")
    @PostMapping("deleteCar")
    private Result deleteCar(@PathVariable Integer carId){
        realService.deleteCar(carId);
        Result result = Result.success();
        return result;
    }



}
