package com.fivegroup.system.controller;

import com.fivegroup.common.core.utils.poi.ExcelUtil;
import com.fivegroup.common.core.web.controller.BaseController;
import com.fivegroup.common.core.domain.Result;
import com.fivegroup.common.core.web.page.TableDataInfo;
import com.fivegroup.common.log.annotation.Log;
import com.fivegroup.common.log.enums.BusinessType;
import com.fivegroup.common.security.annotation.InnerAuth;
import com.fivegroup.common.security.annotation.RequiresPermissions;
import com.fivegroup.common.system.domain.SysOperLog;
import com.fivegroup.system.service.SysOperLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 操作日志记录
 *
 * @author fivegroup
 */
@RestController
@RequestMapping("/operlog")
public class SysOperlogController extends BaseController {
    @Autowired
    private SysOperLogService operLogService;

    @RequiresPermissions("system:operlog:list")
    @GetMapping("/list")
    public Result<TableDataInfo<SysOperLog>> list (SysOperLog operLog) {
        startPage();
        List<SysOperLog> list = operLogService.selectOperLogList(operLog);
        return getDataTable(list);
    }

    @Log(title = "操作日志", businessType = BusinessType.EXPORT)
    @RequiresPermissions("system:operlog:export")
    @PostMapping("/export")
    public void export (HttpServletResponse response, SysOperLog operLog) {
        List<SysOperLog> list = operLogService.selectOperLogList(operLog);
        ExcelUtil<SysOperLog> util = new ExcelUtil<SysOperLog>(SysOperLog.class);
        util.exportExcel(response, list, "操作日志");
    }

    @Log(title = "操作日志", businessType = BusinessType.DELETE)
    @RequiresPermissions("system:operlog:remove")
    @DeleteMapping("/{operIds}")
    public Result remove (@PathVariable Long[] operIds) {
        return toAjax(operLogService.deleteOperLogByIds(operIds));
    }

    @RequiresPermissions("system:operlog:remove")
    @Log(title = "操作日志", businessType = BusinessType.CLEAN)
    @DeleteMapping("/clean")
    public Result clean () {
        operLogService.cleanOperLog();
        return success();
    }

    @InnerAuth
    @PostMapping
    public Result add (@RequestBody SysOperLog operLog) {
        return toAjax(operLogService.insertOperlog(operLog));
    }
}
